Class: Charming::Events::ResizeEvent

Inherits:
Data
  • Object
show all
Defined in:
lib/charming/events/resize_event.rb

Overview

ResizeEvent represents a terminal window resize. width and height carry the new terminal dimensions in screen cells, replacing the previous Screen dimensions for all subsequent rendering.

Instance Attribute Summary collapse

Instance Attribute Details

#heightObject (readonly)

Returns the value of attribute height

Returns:

  • (Object)

    the current value of height



7
8
9
# File 'lib/charming/events/resize_event.rb', line 7

def height
  @height
end

#widthObject (readonly)

Returns the value of attribute width

Returns:

  • (Object)

    the current value of width



7
8
9
# File 'lib/charming/events/resize_event.rb', line 7

def width
  @width
end