Class: Charming::Events::TimerEvent
- Inherits:
-
Data
- Object
- Data
- Charming::Events::TimerEvent
- Defined in:
- lib/charming/events/timer_event.rb
Overview
TimerEvent represents a timed dispatch from the runtime loop. name is the declared timer identifier; now is the monotonically rising clock value at emission for throttle comparisons.
Instance Attribute Summary collapse
-
#name ⇒ Object
readonly
Returns the value of attribute name.
-
#now ⇒ Object
readonly
Returns the value of attribute now.
Instance Attribute Details
#name ⇒ Object (readonly)
Returns the value of attribute name
7 8 9 |
# File 'lib/charming/events/timer_event.rb', line 7 def name @name end |
#now ⇒ Object (readonly)
Returns the value of attribute now
7 8 9 |
# File 'lib/charming/events/timer_event.rb', line 7 def now @now end |