Class: Charming::ResizeEvent

Inherits:
Data
  • Object
show all
Defined in:
lib/charming/resize_event.rb

Overview

ResizeEvent represents a terminal window resize. width and height carry the new terminal dimensions in screen cells, replacing the previous Screen dimensions for all subsequent rendering.

Instance Attribute Summary collapse

Instance Attribute Details

#heightObject (readonly)

Returns the value of attribute height

Returns:

  • (Object)

    the current value of height



6
7
8
# File 'lib/charming/resize_event.rb', line 6

def height
  @height
end

#widthObject (readonly)

Returns the value of attribute width

Returns:

  • (Object)

    the current value of width



6
7
8
# File 'lib/charming/resize_event.rb', line 6

def width
  @width
end