Class: Charming::TimerEvent

Inherits:
Data
  • Object
show all
Defined in:
lib/charming/timer_event.rb

Overview

TimerEvent represents a timed dispatch from the runtime loop. name is the declared timer identifier; now is the monotonically rising clock value at emission for throttle comparisons.

Instance Attribute Summary collapse

Instance Attribute Details

#nameObject (readonly)

Returns the value of attribute name

Returns:

  • (Object)

    the current value of name



6
7
8
# File 'lib/charming/timer_event.rb', line 6

def name
  @name
end

#nowObject (readonly)

Returns the value of attribute now

Returns:

  • (Object)

    the current value of now



6
7
8
# File 'lib/charming/timer_event.rb', line 6

def now
  @now
end