Class: Charming::Component

Inherits:
View
  • Object
show all
Defined in:
lib/charming/component.rb

Overview

Component is the base class for all reusable terminal widgets. It inherits from View to gain assigns, helper methods (text, box, row, column, etc.), and rendering via render.

Method Summary

Methods inherited from View

#focused?, #initialize, #layout_assigns, #render

Constructor Details

This class inherits a constructor from Charming::View