Class: Charming::Component
Overview
Component is the base class for all reusable terminal widgets. It inherits from View to gain assigns, helper methods (text, box, row, column, etc.), and rendering via render.
Direct Known Subclasses
Charming::Components::ActivityIndicator, Charming::Components::CommandPalette, Charming::Components::List, Charming::Components::Modal, Charming::Components::Progressbar, Charming::Components::Spinner, Charming::Components::Table, Charming::Components::TextInput, Charming::Components::Viewport
Method Summary
Methods inherited from View
#focused?, #initialize, #layout_assigns, #render
Constructor Details
This class inherits a constructor from Charming::View