Module: Charming::Controller::ComponentDispatching
- Included in:
- Charming::Controller
- Defined in:
- lib/charming/controller/component_dispatching.rb
Overview
Component-dispatch helpers mixed into Controller. Forwards key events to the currently focused component (the slot returned by ‘focus.current`) and translates component return values into controller hook calls (e.g., `slot_submitted`, `slot_selected`, `slot_cancelled`).