Class: Charming::Events::ResizeEvent
- Inherits:
-
Data
- Object
- Data
- Charming::Events::ResizeEvent
- Defined in:
- lib/charming/events/resize_event.rb
Overview
ResizeEvent represents a terminal window resize. width and height carry the new terminal dimensions in screen cells, replacing the previous Screen dimensions for all subsequent rendering.
Instance Attribute Summary collapse
-
#height ⇒ Object
readonly
Returns the value of attribute height.
-
#width ⇒ Object
readonly
Returns the value of attribute width.
Instance Attribute Details
#height ⇒ Object (readonly)
Returns the value of attribute height
7 8 9 |
# File 'lib/charming/events/resize_event.rb', line 7 def height @height end |
#width ⇒ Object (readonly)
Returns the value of attribute width
7 8 9 |
# File 'lib/charming/events/resize_event.rb', line 7 def width @width end |