Class: Charming::ResizeEvent
- Inherits:
-
Data
- Object
- Data
- Charming::ResizeEvent
- Defined in:
- lib/charming/resize_event.rb
Overview
ResizeEvent represents a terminal window resize. width and height carry the new terminal dimensions in screen cells, replacing the previous Screen dimensions for all subsequent rendering.
Instance Attribute Summary collapse
-
#height ⇒ Object
readonly
Returns the value of attribute height.
-
#width ⇒ Object
readonly
Returns the value of attribute width.
Instance Attribute Details
#height ⇒ Object (readonly)
Returns the value of attribute height
6 7 8 |
# File 'lib/charming/resize_event.rb', line 6 def height @height end |
#width ⇒ Object (readonly)
Returns the value of attribute width
6 7 8 |
# File 'lib/charming/resize_event.rb', line 6 def width @width end |